/*
 * Functions for Call-WWL and DXCC-WWL databases
 * Imported from project tucnak (http://tucnak.nagano.cz)
 */

#ifndef _CDWDB_H_
#define _CDWDB_H_

#include "osdep.h"
#ifdef HAVE_GLIB2
//#warning Compiling with GPL & GLIB2 code!

#include <glib.h>

struct cw_item {
   gchar *wwl0, *wwl1;    
   gint stamp0, stamp1;
   gint qrv;                /* bit array, lsb = A = 50MHz etc. Since 1.15 */
};

struct wc_item {
   gchar *call0, *call1;    
   gint stamp0, stamp1;
};

struct cw {
    GHashTable *cw; /* key=call, value=cw_item */
    GHashTable *wc;
    int latest;
};

struct dw_item {
    gchar *wwl0, *wwl1;   /* center of activity (optional),  */
                            /* center of dxcc (geometric)     */
    GHashTable *wwls;      /* all wwls valid for this dxcc */
};

struct wd_item {
    gchar *dxc0, *dxc1;
};

struct dw {
    GHashTable *pd;  /* key=prefix "DF", value=dxcc (main prefix) "DL" */
    GHashTable *dw;  /* key=dxcc "DL", value=dw_item */
    GHashTable *wd;  /* key=big wwl, "JN69" */
};



extern struct cw *cw;
extern struct dw *dw;

struct cw *init_cw();
void free_cw(struct cw *cw);
gchar *find_wwl_by_call(struct cw *cw, gchar *call);
gchar *find_call_by_wwl(struct cw *cw, gchar *wwl);
int load_cw_from_file(struct cw *cw, gchar *filename);


struct dw *init_dw(void);
void free_dw(struct dw *dw);
int load_dw_from_file(struct dw *dw, gchar *filename);
int load_cty_from_file(struct dw *dw, gchar *filename);
int wwl_is_ok_by_call(struct dw *dw, gchar *wwl, gchar *call);
int get_susp(struct cw *cw, struct dw *dw, gchar *call, gchar *wwl);
gchar *find_wwl_by_dxc(struct dw *dw,  gchar *dxc);
gchar *find_dxc_by_wwl(struct dw *dw, gchar *wwl);
char *get_dxcc(struct dw *dw, char *buf, char *call);
void check_susp(void);

#endif /* HAVE_GLIB2 */

/*struct dw_item {
	char *dxc;
	char *wwl;
}*/

#endif /*_CDWDB_H_*/
